@@ -1,14 +1,14 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 
 use warnings;
 use strict;
 
 package Log::Report;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 use base 'Exporter';
 
@@ -73,12 +73,13 @@ sub report($@)
     {   @disp = @{$reporter->{needs}{$reason} || []};
     }
 
-    # return when no-one needs it: skip unused trace() fast!
-    @disp || $stop or return;
-
     is_reason $reason
         or error __x"token '{token}' not recognized as reason", token=>$reason;
 
+    # return when no-one needs it: skip unused trace() fast!
+    @disp || $stop
+        or return;
+
     $opts->{errno} ||= $!+0 || $? || 1
         if use_errno($reason) && !defined $opts->{errno};
 
@@ -154,30 +155,47 @@ sub report($@)
 }
 
 
-my %disp_actions = map +($_ => 1)
- , qw/close find list disable enable mode needs filter active-try/;
+my %disp_actions = map +($_ => 1), qw/
+  close find list disable enable mode needs filter active-try do-not-reopen
+  /;
+
+my $reopen_disp = 1;
 
 sub dispatcher($@)
 {   if(! $disp_actions{$_[0]})
     {   my ($type, $name) = (shift, shift);
 
         # old dispatcher with same name will be closed in DESTROY
-        delete $reporter->{dispatchers}{$name};
+        my $disps = $reporter->{dispatchers};
+        my @disps;
+        if($reopen_disp)
+        {   @disps  = grep $_->name ne $name, @$disps;
+            trace "reopened dispatcher $name" if @disps != @$disps;
+        }
+        else
+        {   my $has = first {$_->name eq $name} @$disps;
+            if(defined $has)
+            {   trace "not reopening $name";
+                return $has;
+            }
+            @disps  = @$disps;
+        }
 
-        my $disp = Log::Report::Dispatcher->new($type, $name
-          , mode => $default_mode, @_);
-        defined $disp or return;  # use defined, because $disp is overloaded
+        my $disp = Log::Report::Dispatcher
+           ->new($type, $name, mode => $default_mode, @_);
+
+        push @disps, $disp if $disp;
+        $reporter->{dispatchers} = \@disps;
 
-        $reporter->{dispatchers}{$name} = $disp;
         _whats_needed;
-        return ($disp);
+        return $disp ? ($disp) : undef;
     }
 
     my $command = shift;
     if($command eq 'list')
     {   mistake __"the 'list' sub-command doesn't expect additional parameters"
            if @_;
-        my @disp = values %{$reporter->{dispatchers}};
+        my @disp = @{$reporter->{dispatchers}};
         push @disp, $nested_tries[-1] if @nested_tries;
         return @disp;
     }
@@ -192,43 +210,52 @@ sub dispatcher($@)
     {   my $code = shift;
         error __"the 'filter' sub-command needs a CODE reference"
             unless ref $code eq 'CODE';
-        my %names = map { ($_ => 1) } @_;
+        my %names = map +($_ => 1), @_;
         push @{$reporter->{filters}}, [ $code, \%names ];
         return ();
     }
     if($command eq 'active-try')
     {   return $nested_tries[-1];
     }
+    if($command eq 'do-not-reopen')
+    {   $reopen_disp = 0;
+        return ();
+    }
 
     my $mode     = $command eq 'mode' ? shift : undef;
 
     my $all_disp = @_==1 && $_[0] eq 'ALL';
-    my @disps    = $all_disp ? keys %{$reporter->{dispatchers}} : @_;
-
-    my @dispatchers = grep defined, @{$reporter->{dispatchers}}{@disps};
-    @dispatchers or return;
+    my $disps    = $reporter->{dispatchers};
+    my @disps;
+    if($all_disp) { @disps = @$disps }
+    else
+    {   # take the dispatchers in the specified order.  Both lists
+        # are small, so O(x²) is small enough
+        for my $n (@_) { push @disps, grep $_->name eq $n, @$disps }
+    }
 
     error __"only one dispatcher name accepted in SCALAR context"
-        if @dispatchers > 1 && !wantarray && defined wantarray;
+        if @disps > 1 && !wantarray && defined wantarray;
 
     if($command eq 'close')
-    {   delete @{$reporter->{dispatchers}}{@disps};
-        $_->close for @dispatchers;
+    {   my %kill = map +($_->name => 1), @disps;
+        @$disps  = grep !$kill{$_->name}, @$disps;
+        $_->close for @disps;
     }
-    elsif($command eq 'enable')  { $_->_disabled(0) for @dispatchers }
-    elsif($command eq 'disable') { $_->_disabled(1) for @dispatchers }
+    elsif($command eq 'enable')  { $_->_disabled(0) for @disps }
+    elsif($command eq 'disable') { $_->_disabled(1) for @disps }
     elsif($command eq 'mode')
     {    Log::Report::Dispatcher->defaultMode($mode) if $all_disp;
-         $_->_set_mode($mode) for @dispatchers;
+         $_->_set_mode($mode) for @disps;
     }
 
     # find does require reinventarization
     _whats_needed if $command ne 'find';
 
-    wantarray ? @dispatchers : $dispatchers[0];
+    wantarray ? @disps : $disps[0];
 }
 
-END { $_->close for grep defined, values %{$reporter->{dispatchers}} }
+END { $_->close for @{$reporter->{dispatchers}} }
 
 # _whats_needed
 # Investigate from all dispatchers which reasons will need to be
@@ -237,7 +264,7 @@ END { $_->close for grep defined, values %{$reporter->{dispatchers}} }
 
 sub _whats_needed()
 {   my %needs;
-    foreach my $disp (values %{$reporter->{dispatchers}})
+    foreach my $disp (@{$reporter->{dispatchers}})
     {   push @{$needs{$_}}, $disp for $disp->needs;
     }
     $reporter->{needs} = \%needs;
