@@ -1,13 +1,13 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Dispatcher::Syslog;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 use base 'Log::Report::Dispatcher';
 
@@ -60,6 +60,7 @@ sub init($)
 
     $self->{LRDS_incl_dom} = delete $args->{include_domain};
     $self->{LRDS_charset}  = delete $args->{charset} || "utf-8";
+    $self->{LRDS_format}   = $args->{format} || sub {$_[0]};
 
     $self->{prio} = +{ %default_reasonToPrio };
     if(my $to_prio = delete $args->{to_prio})
@@ -89,25 +90,32 @@ sub close()
 
 #--------------
 
+sub format(;$)
+{   my $self = shift;
+    @_ ? $self->{LRDS_format} = shift : $self->{LRDS_format};
+}
+
 #--------------
 
 sub log($$$$$)
 {   my ($self, $opts, $reason, $msg, $domain) = @_;
-    my $text = encode $self->{LRDS_charset}
-      , $self->translate($opts, $reason, $msg) or return;
-
-    my $prio = $self->reasonToPrio($reason);
+    my $text   = $self->translate($opts, $reason, $msg) or return;
+    my $format = $self->format;
 
     # handle each line in message separately
     $text    =~ s/\s+$//s;
-    my @text = split /\n/, $text;
+    my @text = split /\n/, $format->($text, $domain, $msg);
+
+    my $prio    = $self->reasonToPrio($reason);
+    my $charset = $self->{LRDS_charset};
 
     if($self->{LRDS_incl_dom} && $domain)
     {   $domain  =~ s/\%//g;    # security
-        syslog $prio, "$domain %s", shift @text
+        syslog $prio, "$domain %s", encode($charset, shift @text);
     }
 
-    syslog $prio, "%s", $_ for @text;
+    syslog $prio, "%s", encode($charset, $_)
+        for @text;
 }
 
 
