@@ -1,18 +1,19 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Dispatcher::Try;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 use base 'Log::Report::Dispatcher';
 
 use Log::Report 'log-report', syntax => 'SHORT';
-use Log::Report::Exception;
+use Log::Report::Exception ();
+use Log::Report::Util      qw/%reason_code/;
 
 
 use overload
@@ -27,14 +28,7 @@ sub init($)
     defined $self->SUPER::init($args) or return;
     $self->{exceptions} = delete $args->{exceptions} || [];
     $self->{died}       = delete $args->{died};
-
-    if(my $h = $args->{hide})
-    {   my @h = ref $h eq 'ARRAY' ? @$h : defined $h ? $h : ();
-        $self->{hides}
-           = @h==0 ? undef
-           : @h==1 && $h[0] eq 'ALL' ? {} # empty HASH = ALL
-           :    +{ map +($_ => 1), @h };
-    }
+    $self->hide($args->{hide} // 'NONE');
     $self;
 }
 
@@ -61,14 +55,31 @@ sub hides($)
     keys %$h ? $h->{(shift)} : 1;
 }
 
+
+sub hide(@)
+{   my $self = shift;
+    my @h = map { ref $_ eq 'ARRAY' ? @$_ : defined($_) ? $_ : () } @_;
+
+    $self->{hides}
+      = @h==0 ? undef
+      : @h==1 && $h[0] eq 'ALL'  ? {}    # empty HASH = ALL
+      : @h==1 && $h[0] eq 'NONE' ? undef
+      :    +{ map +($_ => 1), @h };
+}
+
 #-----------------
 
 sub log($$$$)
 {   my ($self, $opts, $reason, $message, $domain) = @_;
 
-    # If "try" does not want a stack, because of its mode,
-    # then don't produce one later!  (too late)
-    $opts->{stack}    ||= [];
+    unless($opts->{stack})
+    {   my $mode = $self->mode;
+        $opts->{stack} = $self->collectStack
+            if $reason eq 'PANIC'
+            || ($mode==2 && $reason_code{$reason} >= $reason_code{ALERT})
+            || ($mode==3 && $reason_code{$reason} >= $reason_code{ERROR});
+    }
+
     $opts->{location} ||= '';
 
     my $e = Log::Report::Exception->new
