@@ -1,13 +1,13 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Domain;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 use base 'Log::Report::Minimal::Domain';
 
@@ -83,7 +83,19 @@ sub setContext(@)
     my $cr   = $self->contextRules  # ignore context if no rules given
         or return;
 
-    $self->{LRD_ctxt_def} = $cr->needDecode(setContext => shift);
+    $self->{LRD_ctxt_def} = $cr->needDecode(set => @_);
+}
+
+
+sub updateContext(@)
+{   my $self = shift;
+    my $cr   = $self->contextRules  # ignore context if no rules given
+        or return;
+
+    my $rules = $cr->needDecode(update => @_);
+    my $r = $self->{LRD_ctxt_def} ||= {};
+    @{$r}{keys %$r} = values %$r;
+    $r;
 }
 
 
