@@ -1,13 +1,13 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Exception;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 
 use Log::Report      'log-report';
@@ -68,7 +68,7 @@ sub throw(@)
     }
 
     $opts->{stack} = Log::Report::Dispatcher->collectStack
-        if $opts->{stack} && @{$opts->{stack}};
+        unless $opts->{stack} && @{$opts->{stack}};
 
     report $opts, $reason, $self;
 }
