@@ -1,13 +1,13 @@
 # Copyrights 2007-2015 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 
 use Log::Report 'log-report';
@@ -133,10 +133,8 @@ sub toString(;$)
   
     defined $text or return ();
 
-    if($self->{_expand})
-    {    my $re   = join '|', map quotemeta, keys %$self;
-         $text    =~ s/\{($re)(\%[^}]*)?\}/$self->_expand($1,$2)/ge;
-    }
+    $text  =~ s/\{([^%}]+)(\%[^}]*)?\}/$self->_expand($1,$2)/ge
+        if $self->{_expand};
 
     $text  = "$self->{_prepend}$text"
         if defined $self->{_prepend};
@@ -152,7 +150,7 @@ sub toString(;$)
 
 sub _expand($$)
 {   my ($self, $key, $format) = @_;
-    my $value = $self->{$key};
+    my $value = $self->{$key} // $self->{_context}{$key};
 
     $value = $value->($self)
         while ref $value eq 'CODE';
